@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
-from message import Message
+from __future__ import absolute_import, unicode_literals
+from .message import Message
 from gestionatr.input.messages.C2 import Direccion
 from gestionatr.defs import TARIFES_SEMPRE_MAX, TARIFES_TD
 from datetime import datetime, date, timedelta
 from gestionatr.utils import repartir_consums_entre_lectures
+import six
 
 # Magnituds d'OCSUM
 MAGNITUDS_OCSUM = {
@@ -84,6 +86,11 @@ CODIS_AUTOCONSUM = {
     '82': 'informacio',
 }
 
+CODIS_INDEMNITZACIO_AUTOCONSUM = {
+    '86': 'Descuento por retardo en activación autoconsumo imputable al distribuidor',
+    '87': 'Descuento por retardo en activación autoconsumo NO imputable al distribuidor',
+}
+
 # Totalitzadors a ignorar
 SKIP_TOTALITZADORS = ('00', '60')
 
@@ -524,7 +531,7 @@ class Factura(object):
                     continue
                 elif concepte.is_autoconsum():
                     conceptes.append(concepte)
-                elif concepte.importe:
+                elif concepte.importe or concepte.is_indemnitzacio():
                     total += concepte.importe
                     conceptes.append(concepte)
         except AttributeError:
@@ -2369,7 +2376,7 @@ class FacturaATR(Factura):
 
             di, df = aparell_multi.get_dates_inici_i_final()
             comptadors.append((di, df, aparell_multi))
-        return [a[2] for a in sorted(comptadors, lambda x,y: cmp(x[0], y[0]))]
+        return [a[2] for a in sorted(comptadors, key=lambda x: x[0])]
 
     def get_info_potencia(self):
         """Retorna els periodes de potència"""
@@ -2598,6 +2605,10 @@ class ConceptoRepercutible(object):
     def is_autoconsum(self):
         return self.concepto_repercutible in CODIS_AUTOCONSUM.keys()
 
+    def is_indemnitzacio(self):
+        return self.concepto_repercutible in CODIS_INDEMNITZACIO_AUTOCONSUM.keys()
+
+
 class OtraFactura(Factura):
     DATOS_GENERALES_NAME = 'DatosGeneralesOtrasFacturas'
     DATOS_GENERALES_OBJECT = DatosGeneralesOtras
